X-Git-Url: https://git.saurik.com/wxWidgets.git/blobdiff_plain/854e189f90dac9ba5e0239bca79aed64e8d6f46c..288b6107e1060b57ec50048d06cfc3f22bc11e0c:/include/wx/xrc/xh_spin.h?ds=sidebyside

diff --git a/include/wx/xrc/xh_spin.h b/include/wx/xrc/xh_spin.h
index 7448302b7d..c2b23b1b50 100644
--- a/include/wx/xrc/xh_spin.h
+++ b/include/wx/xrc/xh_spin.h
@@ -1,6 +1,6 @@
 /////////////////////////////////////////////////////////////////////////////
 // Name:        xh_spin.h
 // Purpose:     XML resource handler for wxSpinButton
 // Author:      Bob Mitchell
 // Created:     2000/03/21
 // RCS-ID:      $Id$
@@ -11,17 +11,15 @@
 #ifndef _WX_XH_SPIN_H_
 #define _WX_XH_SPIN_H_
 
-#if defined(__GNUG__) && !defined(__APPLE__)
-#pragma interface "xh_spin.h"
-#endif
-
 #include "wx/xrc/xmlres.h"
-#include "wx/defs.h"
+
+#if wxUSE_XRC 
 
 #if wxUSE_SPINBTN
-class WXXMLDLLEXPORT wxSpinButtonXmlHandler : public wxXmlResourceHandler
+
+class WXDLLIMPEXP_XRC wxSpinButtonXmlHandler : public wxXmlResourceHandler
 {
-	DECLARE_DYNAMIC_CLASS(wxSpinButtonXmlHandler)
+    DECLARE_DYNAMIC_CLASS(wxSpinButtonXmlHandler)
     enum
     {
         wxSP_DEFAULT_VALUE = 0,
@@ -34,12 +32,15 @@ public:
     virtual wxObject *DoCreateResource();
     virtual bool CanHandle(wxXmlNode *node);
 };
-#endif
+
+#endif // wxUSE_SPINBTN
+
 
 #if wxUSE_SPINCTRL
-class WXXMLDLLEXPORT wxSpinCtrlXmlHandler : public wxXmlResourceHandler
+
+class WXDLLIMPEXP_XRC wxSpinCtrlXmlHandler : public wxXmlResourceHandler
 {
-	DECLARE_DYNAMIC_CLASS(wxSpinCtrlXmlHandler)
+    DECLARE_DYNAMIC_CLASS(wxSpinCtrlXmlHandler)
     enum
     {
         wxSP_DEFAULT_VALUE = 0,
@@ -52,6 +53,9 @@ public:
     virtual wxObject *DoCreateResource();
     virtual bool CanHandle(wxXmlNode *node);
 };
-#endif
+
+#endif // wxUSE_SPINCTRL
+
+#endif // wxUSE_XRC
 
 #endif // _WX_XH_SPIN_H_
@@ -1,6 +1,6 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        xh_spin.h
-// Purpose:     XML resource handler for wxSpinButton
+// Name:        wx/xrc/xh_spin.h
+// Purpose:     XML resource handler for wxSpinButton and wxSpinCtrl
 // Author:      Bob Mitchell
 // Created:     2000/03/21